tonalanalysistools.Scale
========================

.. abjad-lineage:: abjad.tools.tonalanalysistools.Scale.Scale

.. autoclass:: abjad.tools.tonalanalysistools.Scale.Scale

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.tonalanalysistools.Scale.Scale.alpha
      ~abjad.tools.tonalanalysistools.Scale.Scale.count
      ~abjad.tools.tonalanalysistools.Scale.Scale.create_named_pitch_set_in_pitch_range
      ~abjad.tools.tonalanalysistools.Scale.Scale.custom_identifier
      ~abjad.tools.tonalanalysistools.Scale.Scale.dominant
      ~abjad.tools.tonalanalysistools.Scale.Scale.from_selection
      ~abjad.tools.tonalanalysistools.Scale.Scale.has_duplicates
      ~abjad.tools.tonalanalysistools.Scale.Scale.index
      ~abjad.tools.tonalanalysistools.Scale.Scale.invert
      ~abjad.tools.tonalanalysistools.Scale.Scale.is_equivalent_under_transposition
      ~abjad.tools.tonalanalysistools.Scale.Scale.item_class
      ~abjad.tools.tonalanalysistools.Scale.Scale.key_signature
      ~abjad.tools.tonalanalysistools.Scale.Scale.leading_tone
      ~abjad.tools.tonalanalysistools.Scale.Scale.make_notes
      ~abjad.tools.tonalanalysistools.Scale.Scale.make_score
      ~abjad.tools.tonalanalysistools.Scale.Scale.mediant
      ~abjad.tools.tonalanalysistools.Scale.Scale.multiply
      ~abjad.tools.tonalanalysistools.Scale.Scale.named_interval_class_segment
      ~abjad.tools.tonalanalysistools.Scale.Scale.named_pitch_class_to_scale_degree
      ~abjad.tools.tonalanalysistools.Scale.Scale.retrograde
      ~abjad.tools.tonalanalysistools.Scale.Scale.rotate
      ~abjad.tools.tonalanalysistools.Scale.Scale.scale_degree_to_named_pitch_class
      ~abjad.tools.tonalanalysistools.Scale.Scale.subdominant
      ~abjad.tools.tonalanalysistools.Scale.Scale.submediant
      ~abjad.tools.tonalanalysistools.Scale.Scale.superdominant
      ~abjad.tools.tonalanalysistools.Scale.Scale.tonic
      ~abjad.tools.tonalanalysistools.Scale.Scale.transpose
      ~abjad.tools.tonalanalysistools.Scale.Scale.__add__
      ~abjad.tools.tonalanalysistools.Scale.Scale.__contains__
      ~abjad.tools.tonalanalysistools.Scale.Scale.__eq__
      ~abjad.tools.tonalanalysistools.Scale.Scale.__format__
      ~abjad.tools.tonalanalysistools.Scale.Scale.__getitem__
      ~abjad.tools.tonalanalysistools.Scale.Scale.__getslice__
      ~abjad.tools.tonalanalysistools.Scale.Scale.__hash__
      ~abjad.tools.tonalanalysistools.Scale.Scale.__iter__
      ~abjad.tools.tonalanalysistools.Scale.Scale.__len__
      ~abjad.tools.tonalanalysistools.Scale.Scale.__makenew__
      ~abjad.tools.tonalanalysistools.Scale.Scale.__mul__
      ~abjad.tools.tonalanalysistools.Scale.Scale.__ne__
      ~abjad.tools.tonalanalysistools.Scale.Scale.__repr__
      ~abjad.tools.tonalanalysistools.Scale.Scale.__rmul__
      ~abjad.tools.tonalanalysistools.Scale.Scale.__str__

Bases
-----

- :py:class:`pitchtools.PitchClassSegment <abjad.tools.pitchtools.PitchClassSegment.PitchClassSegment>`

- :py:class:`pitchtools.Segment <abjad.tools.pitchtools.Segment.Segment>`

- :py:class:`datastructuretools.TypedTuple <abjad.tools.datastructuretools.TypedTuple.TypedTuple>`

- :py:class:`datastructuretools.TypedCollection <abjad.tools.datastructuretools.TypedCollection.TypedCollection>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.tonalanalysistools.Scale.Scale.dominant
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.Scale.Scale.has_duplicates
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.Scale.Scale.item_class
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.Scale.Scale.key_signature
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.Scale.Scale.leading_tone
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.Scale.Scale.mediant
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.Scale.Scale.named_interval_class_segment
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.Scale.Scale.subdominant
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.Scale.Scale.submediant
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.Scale.Scale.superdominant
   :noindex:

.. autoattribute:: abjad.tools.tonalanalysistools.Scale.Scale.tonic
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.tonalanalysistools.Scale.Scale.custom_identifier
   :noindex:

Methods
-------

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.alpha
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.count
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.create_named_pitch_set_in_pitch_range
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.index
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.invert
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.is_equivalent_under_transposition
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.make_notes
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.make_score
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.multiply
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.named_pitch_class_to_scale_degree
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.retrograde
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.rotate
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.scale_degree_to_named_pitch_class
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.transpose
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.from_selection
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.__add__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.__contains__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.__eq__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.__format__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.__getitem__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.__getslice__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.__hash__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.__iter__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.__len__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.__makenew__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.__mul__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.__ne__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.__repr__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.__rmul__
   :noindex:

.. automethod:: abjad.tools.tonalanalysistools.Scale.Scale.__str__
   :noindex:
